# frozen_string_literal: true

require 'net/http'
require 'json'

module Crossbelt
  module Plugins
    module Exporters
      class Xbui
        def self.requires
          [:none]
        end

        def self.utilizies
          [:json]
        end

        def self.type
          'exporter'
        end

        def self.version
          '0.0.1'
        end

        def self.name
          'xbui'
        end

        def self.description
          'Outputs data to XBUI'
        end

        def self.to_h
          {
            name: name,
            type: type,
            version: version,
            desc: description
          }
        end

        def self.export(contents: nil, context: Object.new)
          uri = URI('https://emjqbdo9s1.execute-api.us-east-1.amazonaws.com/dev/')
          req_options = {
            read_timeout: 5,
            use_ssl: uri.scheme == 'https'
          }
          metadata = {
            rigId: context.config.read_config('rigId', 'none'),
            owner: 'me',
            rigName: context.rig.nickname || context.rig.name
          }

          request = Net::HTTP::Post.new(uri.path)
          request.body = context.rig.to_h.merge(metadata).to_json
          request.content_type = 'application/json'

          response = Net::HTTP.start(uri.hostname, uri.port, req_options) do |http|
            http.request(request)
          end
          if response.code == '200'
            response.body
          else
            'Failed to send data'
          end
        end
      end
    end
  end
end
